@@ -20,23 +20,26 @@ EmissionDistFn = Callable[ [Float[Array, "state_dim"], Float[Array, "state_dim s
 
 class ParamsGGSSM(NamedTuple):
     """
-    Container for GGSSM parameters. Differs from NLGSSM in terms of emission model.
-    
-    The tuple doubles as a container for the ParameterProperties.
+    Container for Generalized Gaussian SSM parameters. 
+    Specifically, it defines the following model:
 
     $$p(z_t | z_{t-1}, u_t) = N(z_t | f(z_{t-1}, u_t), Q_t)$$
     $$p(y_t | z_t) = q(y_t | h(z_t, u_t), R(z_t, u_t))$$
     $$p(z_1) = N(z_1 | m, S)$$
 
+    This differs from NLGSSM in by allowing a general emission model.
+    If you have no inputs, the dynamics and emission functions do not to take $u_t$ as an argument.
+
     :param initial_mean: $m$
     :param initial_covariance: $S$
-    :param dynamics_function: $f$
+    :param dynamics_function: $f$. This has the signature $f: Z * U -> Y$ or $h: Z -> Y$.
     :param dynamics_covariance: $Q$
-    :param emissions_mean_function: $h$
-    :param emissions_cov_function: $R$
-    :param emission_dist: the observation pdf $q$. Constructed from specified mean and covariance.
+    :param emission_mean_function: $h$. This has the signature $h: Z * U -> Z$ or $h: Z -> Z$.
+    :param emission_cov_function: $R$. This has the signature $R: Z * U -> Z*Z$ or $R: Z -> Z*Z$.
+    :param emission_dist: the observation distribution $q$. This is a callable that takes the predicted
+              mean and covariance of Y, and returns a tfp distribution object: $q: Z * (Z*Z) -> Dist(Y)$.
+
 
-    If you have no inputs, the dynamics and emission functions do not to take $u_t$ as an argument.
     """
 
     initial_mean: Float[Array, "state_dim"]
@@ -46,7 +49,7 @@ class ParamsGGSSM(NamedTuple):
 
     emission_mean_function: Union[FnStateToEmission, FnStateAndInputToEmission]
     emission_cov_function: Union[FnStateToEmission2, FnStateAndInputToEmission2]
-    emission_dist: EmissionDistFn = MVN
+    emission_dist: EmissionDistFn = lambda mean, cov: MVN(loc=mean, covariance_matrix=cov)
 
 
 
@@ -60,7 +63,7 @@ class GeneralizedGaussianSSM(SSM):
     $$p(y_t | z_t) = q(y_t | h(z_t, u_t), R(z_t, u_t))$$
     $$p(z_1) = N(z_1 | m, S)$$
 
-    where
+    where the model parameters are
 
     * $z_t$ = hidden variables of size `state_dim`,
     * $y_t$ = observed variables of size `emission_dim`
@@ -72,6 +75,10 @@ class GeneralizedGaussianSSM(SSM):
     * $m$ = mean of initial state
     * $S$ = covariance matrix of initial state
 
+    The parameters of the model are stored in a separate object of type :class:`ParamsGGSSM`.
+
+    For example usage, see https://github.com/probml/dynamax/blob/main/dynamax/generalized_gaussian_ssm/models_test.py.
+
     """
 
     def __init__(self, state_dim, emission_dim, input_dim=0):
