@@ -196,3 +196,8 @@ def find_permutation(
     overlap = compute_state_overlap(z1, z2)
     _, perm = linear_sum_assignment(-overlap)
     return perm
+
+
+def psd_solve(A,b):
+    """A wrapper for coordinating the linalg solvers used in the library for psd matrices."""
+    return jnp.linalg.solve(A,b)
\ No newline at end of file
